==> rheolef_5.92.orig.tar.gz: rheolef-5.92/skit/ptst2/vec_exchange2_tst.cc <==
///
/// This file is part of Rheolef.
///
/// Copyright (C) 2000-2009 Pierre Saramito <Pierre.Saramito@imag.fr>
///
/// Rheolef is free software; you can redistribute it and/or modify
/// it under the terms of the GNU General Public License as published by
/// the Free Software Foundation; either version 2 of the License, or
/// (at your option) any later version.
///
/// Rheolef is distributed in the hope that it will be useful,
/// but WITHOUT ANY WARRANTY; without even the implied warranty of
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/// GNU General Public License for more details.
///
/// You should have received a copy of the GNU General Public License
/// along with Rheolef; if not, write to the Free Software
/// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
///
/// =========================================================================
# include "rheolef/array.h"
using namespace rheolef;
using namespace std;
int main(int argc, char**argv)
{
    environment parallel(argc, argv);

    size_t n = 101;
    array<Float> x;
    if (x.comm().rank() == 0)
        x.resize(n,n);
    else
        x.resize(n,0);

    array<Float>::iterator iter = x.begin();
    array<Float>::iterator last = x.end();
    fill(iter, last, Float(0));

    if (x.comm().rank() == x.comm().size()-1) {
        for (size_t i = 0; i < x.par_size(); i++) {
	    x.set (i,   1000+i+0.5);
        }
    }
    x.assembly();

    pcout << x.par_size() << endl
          << x            << endl;
}

==> rheolef_5.93.orig.tar.gz: rheolef-5.93/skit/ptst2/vec_exchange2_tst.cc <==
///
/// This file is part of Rheolef.
///
/// Copyright (C) 2000-2009 Pierre Saramito <Pierre.Saramito@imag.fr>
///
/// Rheolef is free software; you can redistribute it and/or modify
/// it under the terms of the GNU General Public License as published by
/// the Free Software Foundation; either version 2 of the License, or
/// (at your option) any later version.
///
/// Rheolef is distributed in the hope that it will be useful,
/// but WITHOUT ANY WARRANTY; without even the implied warranty of
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/// GNU General Public License for more details.
///
/// You should have received a copy of the GNU General Public License
/// along with Rheolef; if not, write to the Free Software
/// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
///
/// =========================================================================
# include "rheolef/array.h"
using namespace rheolef;
using namespace std;
int main(int argc, char**argv)
{
    environment distributed(argc, argv);

    size_t n = 101;
    array<Float> x;
    if (x.comm().rank() == 0)
        x.resize(n,n);
    else
        x.resize(n,0);

    array<Float>::iterator iter = x.begin();
    array<Float>::iterator last = x.end();
    fill(iter, last, Float(0));

    if (x.comm().rank() == x.comm().size()-1) {
        for (size_t i = 0; i < x.dis_size(); i++) {
	    x.dis_entry (i) = 1000+i+0.5;
        }
    }
    x.dis_entry_assembly();

    dcout << x.dis_size() << endl
          << x            << endl;
}
